@@ -198,7 +198,7 @@ class Deserialize:
             return None
 
     @classmethod
-    def string(cls, val: Any) -> Optional[str]:
+    def text(cls, val: Any) -> Optional[str]:
         """Return a value as a string. This method does no HTML escaping, so it should
         only be used when HTML escaping is not a concern.
         """
@@ -210,7 +210,7 @@ class Deserialize:
         return sval
 
     @classmethod
-    def _text(
+    def _html_safe_text(
         cls, tags: HtmlTags, attributes: HtmlAttributes, val: Optional[str]
     ) -> Optional[str]:
         if val is None:
@@ -229,20 +229,16 @@ class Deserialize:
         return val
 
     @classmethod
-    def text_with_html(
+    def html_safe_text(
         cls, *, tags: HtmlTags = None, attributes: HtmlAttributes = None
     ) -> Callable[[Optional[str]], Optional[str]]:
         """Maps a value to a string."""
 
         def mapper(val: Optional[str]) -> Optional[str]:
-            return cls._text(tags or [], attributes or {}, val)
+            return cls._html_safe_text(tags or [], attributes or {}, val)
 
         return mapper
 
-    @classmethod
-    def text(cls, val: Any) -> Optional[str]:
-        return cls._text([], {}, val)
-
     @classmethod
     def base64(cls, val: Any) -> Optional[bytes]:
         """Try to parse base64 to bytes."""
